==> icinga2_2.1.1.orig.tar.gz: icinga2-2.1.1/lib/icinga/eventcommand.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2014 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "icinga/eventcommand.hpp"

using namespace icinga;

REGISTER_TYPE(EventCommand);

void EventCommand::Execute(const Checkable::Ptr& checkable)
{
	std::vector<Value> arguments;
	arguments.push_back(checkable);
	InvokeMethod("execute", arguments);
}

==> icinga2_2.2.4.orig.tar.gz: icinga2-2.2.4/lib/icinga/eventcommand.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "icinga/eventcommand.hpp"

using namespace icinga;

REGISTER_TYPE(EventCommand);

void EventCommand::Execute(const Checkable::Ptr& checkable,
    const Dictionary::Ptr& resolvedMacros, bool useResolvedMacros)
{
	std::vector<Value> arguments;
	arguments.push_back(checkable);
	arguments.push_back(resolvedMacros);
	arguments.push_back(useResolvedMacros);
	InvokeMethod("execute", arguments);
}
